@@ -55,7 +55,6 @@ class PeersManager:
         NOTE: this function is BLOCKING.
         it waits until handshake response received, and failed otherwise.
         """
-        logging.getLogger('BitTorrent').debug("Started: {}".format(threading.currentThread()))
         try:
             peer.connect()
         except PeerConnectionFailed:
@@ -136,8 +135,8 @@ class PeersManager:
         peers_to_message = {}
         # Extract peer from given sockets
         for _peer in self.connected_peers:
-            for readable in readable:
-                if _peer.socket == readable:
+            for should_read in readable:
+                if _peer.socket == should_read:
                     peers_to_message[_peer] = None
 
         # Receive messages from all the given peers
